@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.123';
+our $VERSION = '0.124';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1683,12 +1683,13 @@ sub _set_operational_status {
 #
 # Generated by Astro::SpaceTrack
 # $ tools/all_iridium_classic -iridium -indent=0
-# on Fri Jun 28 14:43:33 2019 GMT
+# on Wed Jul 24 16:04:51 2019 GMT
 #
 # The following static method is UNSUPPORTED, and exists solely for the
 # benefit of xt/author/iridium_status.t. It may be modified or revoked
 # at any time.
-sub __iridium_status_as_of { return( qw{ 55 43 4 28 5 2019 } ) }
+# Time hand-updated for Sladen.
+sub __iridium_status_as_of { return( qw{ 39 5 11 25 6 2019 } ) }
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1745,7 +1746,7 @@ __PACKAGE__->status( add => 25171, iridium => 'D', 'Iridium 54', 'Decayed 2019-0
 __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
 __PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
-__PACKAGE__->status( add => 25263, iridium => '-', 'Iridium 61', 'Tumbling' );
+__PACKAGE__->status( add => 25263, iridium => 'D', 'Iridium 61', 'Decayed 2019-07-23' );
 __PACKAGE__->status( add => 25272, iridium => 'D', 'Iridium 55', 'Decayed 2019-03-31' );
 __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
 __PACKAGE__->status( add => 25274, iridium => 'D', 'Iridium 58', 'Decayed 2019-04-07' );
@@ -1792,8 +1793,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 0
 #       Spare [S]: 1
-#    Tumbling [-]: 33
-#     Decayed [D]: 63
+#    Tumbling [-]: 32
+#     Decayed [D]: 64
 
 1;
 
